@@ -3,11 +3,10 @@ import re
 import secrets
 import sys
 
-import xerox
 from colorama import Fore, Style
 
 from witaker.clipboardserver import (
-    app,
+    create_default_flask_app,
     name,
     version,
     DEFAULT_SERVER_PORT,
@@ -77,9 +76,9 @@ def clipboard_server_cli_main():
     
     print(f" * Initializing {program_version_color(name, version)}  -  {get_auth_marker_color(port, secret_auth_key)}")
 
-    clipboard_util = AuthorizedClipboardUtil(secret_auth_key)
-    clipboard_util.copy_text_to_clipboard(secret_auth_key, get_auth_marker(port, secret_auth_key))
-    app.config["clipboard_util"] = clipboard_util
+    app = create_default_flask_app()
+    app.set_key(secret_auth_key)
+    app.util.copy_text_to_clipboard(secret_auth_key, get_auth_marker(port, secret_auth_key))
 
-    start_flask_webserver(port)
+    start_flask_webserver(app.util, port)
     return 0
