@@ -2,9 +2,9 @@ import argparse
 import signal
 
 from witaker.clipboardserver import (
-    app,
     name,
     version,
+    create_flask_app,
     AuthorizedClipboardUtil,
     add_program_arguments,
     if_version_print_version_and_exit,
@@ -38,14 +38,8 @@ def clipboard_server_gui_main():
     port = get_port_or_default_port(args)
     secret_auth_key = get_auth_key_or_generate_auth_key(args)
     print(f" * Initializing GUI for {program_version_color(name, version)}")
-    clipboard_util = AuthorizedClipboardUtil(secret_auth_key)
-
-    app.config["clipboard_util"] = clipboard_util
-
-    gui = ClipboardServerApp()
-    gui.set_queue(clipboard_util.queue)
-    gui.set_secret_auth_key(secret_auth_key)
-    gui.set_clipboard_util(clipboard_util)
+    
+    gui = ClipboardServerApp(secret_auth_key)
     gui.set_server_port(port)
     gui.run()
     return 0
